@@ -1,16 +1,16 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/GeometryVisitor.h>
-#include <SFCGAL/MultiPoint.h>
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/GeometryVisitor.h"
 
 namespace SFCGAL {
 
 ///
 ///
 ///
-MultiPoint::MultiPoint() : GeometryCollection() {}
+MultiPoint::MultiPoint() = default;
 
 ///
 ///
