@@ -1,13 +1,13 @@
 // Copyright (c) 2012-2013, IGN France.
 // Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef _SFCGAL_DETAIL_FORCEVALIDITY_VISITOR_H_
 #define _SFCGAL_DETAIL_FORCEVALIDITY_VISITOR_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/GeometryVisitor.h>
+#include "SFCGAL/GeometryVisitor.h"
 
 namespace SFCGAL {
 namespace detail {
