@@ -5,9 +5,9 @@
 #ifndef _SFCGAL_TRIANGULATE_IN_GEOMETRY_SET_H_
 #define _SFCGAL_TRIANGULATE_IN_GEOMETRY_SET_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/detail/GeometrySet.h>
+#include "SFCGAL/detail/GeometrySet.h"
 
 namespace SFCGAL {
 namespace triangulate {
