@@ -2,11 +2,11 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 #ifdef SFCGAL_WITH_OSG
 
-#include <SFCGAL/detail/io/OsgFactory.h>
-#include <SFCGAL/io/osg.h>
+#include "SFCGAL/detail/io/OsgFactory.h"
+#include "SFCGAL/io/osg.h"
 
 #include <osg/Geode>
 #include <osg/Geometry>
